@@ -19,9 +19,14 @@ class Redis
 
       protected
         def setnx_with_expire(key, value, ttl, options = {})
-          with_multi_or_pipelined(options) do
-            setnx(key, value, :raw => true)
-            expire(key, ttl)
+          with_multi_or_pipelined(options) do |transaction|
+            if transaction.is_a?(Redis::Store) # for redis < 4.6
+              setnx(key, value, :raw => true)
+              expire(key, ttl)
+            else
+              transaction.setnx(key, value)
+              transaction.expire(key, ttl)
+            end
           end
         end
 
